import React from "react";
import "./clock.css";
/**
 * The properties for this option would not be applicable if `show` is set to `false`
 */
type Ancestorize<T> = {
    show: false;
} | ({
    show?: true;
} & T);
type Strictify<T> = T extends any ? T extends string | number | boolean | bigint | symbol | null | undefined ? T : T extends (...args: any[]) => any ? T : T extends (infer U)[] ? Strictify<U>[] : T extends object ? {
    [K in keyof T]-?: Strictify<T[K]>;
} : T : never;
/**
 * Represents the levels of ticks on the clock, which can be regular, secondary, or primary.
 */
type TickLevel = "regular" | "secondary" | "primary";
/**
 * Options to configure the appearance of individual ticks on the clock.
 * Includes properties such as height, width, background color, and radius.
 */
type TickOptions = Ancestorize<{
    /**
     * The height (px) of the tick (optional).
     */
    height?: number;
    /**
     * The width (px) of the tick (optional).
     */
    width?: number;
    /**
     * The background color of the tick (optional).
     * Any css value is accepted. Example: "black", "rgb(0 0 0 / 0.5)", "linear-gradient()"
     */
    background?: string;
    /**
     * The border radius (px) of the tick (optional).
     */
    radius?: number;
}>;
/**
 * Configuration options for multiple levels of ticks (markings) on the clock.
 * Each tick level (regular, secondary, primary) can be customized with its own options.
 */
type TicksOptions = Ancestorize<{
    [key in TickLevel]?: TickOptions;
}>;
/**
 * Options to configure the appearance of the count numbers on the clock (e.g., hour markers).
 * Includes properties such as size, color, background color, and gap of count from corresponding tick.
 */
type CountOptions = Ancestorize<{
    /**
     * The height and width (px) combined of the count numbers (optional).
     */
    size?: number;
    /**
     * The color of the count numbers (optional).
     * Any css value is accepted. Example: "black", "rgb(0 0 0 / 0.5)", "linear-gradient()"
     */
    color?: string;
    /**
     * The background color of the count numbers (optional).
     * Any css value is accepted. Example: "black", "rgb(0 0 0 / 0.5)", "linear-gradient()"
     */
    background?: string;
    /**
     * The gap (px) between the count numbers and their corresponding tick in the clock (optional).
     */
    gap?: number;
}>;
/**
 * Represents the levels of counts on the clock, excluding the regular tick level.
 */
type CountLevel = Exclude<TickLevel, "regular">;
/**
 * Configuration options for multiple levels of counts on the clock.
 * Each count level (secondary, primary) can be customized with its own options.
 */
type CountsOptions = Ancestorize<Partial<Record<CountLevel, CountOptions>>>;
/**
 * Options to configure the appearance of the clock face.
 * Includes background color, padding, and options for ticks and counts.
 */
type FaceOptions = Ancestorize<{
    /**
     * The background color of the clock face (optional).
     * Any css value is accepted. Example: "black", "rgb(0 0 0 / 0.5)", "linear-gradient()"
     */
    background?: string;
    /**
     * The padding (px) around the edge of clock face (optional).
     */
    padding?: number;
    /**
     * The configuration options for ticks on the clock face (optional).
     */
    ticks?: TicksOptions;
    /**
     * The configuration options for count numbers on the clock face (optional).
     */
    counts?: CountsOptions;
}>;
/**
 * Options to configure the appearance of the clock's central pivot point.
 * Includes size and background color.
 */
type PivotOptions = Ancestorize<{
    /**
     * The height and width (px) combined of the clock's pivot point (optional).
     */
    size?: number;
    /**
     * The background color of the pivot point (optional).
     * Any css value is accepted. Example: "black", "rgb(0 0 0 / 0.5)", "linear-gradient()"
     */
    background?: string;
}>;
/**
 * Represents the possible time units that can be displayed on the clock (hour, minute, second).
 */
type TimeUnit = "hour" | "minute" | "second";
/**
 * A type that represents the different clock hands for time units (e.g., hourHand, minuteHand, secondHand).
 */
type ClockHandName = `${TimeUnit}Hand`;
/**
 * Represents the different subparts of a clock hand, such as front, frontBase, and back.
 */
type HandSubPart = "front" | "frontBase" | "back";
/**
 * Options to configure the appearance of a specific subpart of a clock hand.
 * This includes properties like alignment, background color, radius, width, and height.
 */
type HandSubPartOptions<T extends HandSubPart> = Ancestorize<(T extends "front" ? {
    /**
     * Alignment of the front part of the clock hand (optional).
     * Can be aligned to the PIVOT, TICK, or CENTER.
     * `"PIVOT"` aligns the front part towards the center of the clock.
     * `"TICK"` aligns the front part towards the edge of the clock.
     * `"CENTER"` aligns the front part towards the center of the pivot and edge.
     */
    alignment: "PIVOT" | "TICK" | "CENTER";
} : {}) & {
    /**
     * The background color of the clock hand subpart (optional).
     * Any css value is accepted. Example: "black", "rgb(0 0 0 / 0.5)", "linear-gradient()"
     */
    background?: string;
    /**
     * The border radius (px) of the clock hand subpart (optional).
     */
    radius?: number;
    /**
     * The width (px) of the clock hand subpart (optional).
     */
    width?: number;
    /**
     * The height (px) of the clock hand subpart (optional).
     */
    height?: number;
}>;
/**
 * Options to configure the appearance of the clock hands (hour, minute, second).
 * Each hand can be customized with properties like front, frontBase, and back.
 * frontBase is the base of the front part, that lies below the front part itself.
 * front and back are the subparts of clock hand and are as their names sugges.
 */
type ClockHandOptions = Ancestorize<{
    [K in HandSubPart]?: HandSubPartOptions<K>;
}>;
/**
 * Options to configure the clock's interface behavior and appearance.
 * Includes properties like dynamic behavior, discrete time display, transition speed, and pivot options.
 */
type InterfaceOptions = Ancestorize<{
    /**
     * Enables or disables automatic time updates every second on the clock interface.
     * If true, the clock will automatically update to reflect the current time each second.
     * If false, the time will remain static and not update automatically.
     */
    dynamic?: boolean;
    /**
     * Transition duration (ms) for hand movements (optional).
     */
    transition?: number;
    /**
     * Options to configure the clock's pivot point (optional).
     */
    pivot?: PivotOptions;
} & {
    [key in ClockHandName]?: ClockHandOptions;
}>;
/**
 * Main configuration options for the Clock component.
 * Customize the size, face, and interface of the clock.
 */
export type ClockOptions = {
    /**
     * The height and width (px) combined of the clock (optional).
     */
    size?: number;
    /**
     * Options to configure the appearance of the clock face (optional).
     */
    face?: FaceOptions;
    /**
     * Options to configure the behavior and appearance of the clock interface (optional).
     */
    interface?: InterfaceOptions;
};
export type StrictClockOptions = Strictify<ClockOptions>;
declare const Clock: React.ForwardRefExoticComponent<{
    /**
     * The options object that define the appearance of the clock, and its parts.
     */
    options?: ClockOptions;
    /**
     * A `Date` object that would be used to display time on the clock.
     */
    time?: Date;
    /**
     * Anything that you want to be rendered on the clock face, behind the ticks and clock hands.
     */
    children?: React.ReactNode;
} & React.HTMLAttributes<HTMLDivElement> & React.RefAttributes<HTMLDivElement>>;
export default Clock;
